# virt_s3

* [virt_s3 package](virt_s3.md)
  * [Module contents](virt_s3.md#module-virt_s3)
    * [`get_custom_logger()`](virt_s3.md#virt_s3get_custom_logger)
    * [`PredictConnectionStoreParams`](virt_s3.md#virt_s3PredictCo2nnectionStoreParams)
    * [`S3Params`](virt_s3.md#virt_s3S3Params)
    * [`SessionManager`](virt_s3.md#virt_s3SessionManager)
    * [`TransferConfig`](virt_s3.md#virt_s3TransferConfig)
    * [`LocalFSParams`](virt_s3.md#virt_s3LocalFSParams)
    * [`ImageFormatType`](virt_s3.md#virt_s3ImageFormatType)
    * [`get_default_params()`](virt_s3.md#virt_s3get_default_params)
    * [`get_session_client()`](virt_s3.md#virt_s3get_session_client)
    * [`create_bucket()`](virt_s3.md#virt_s3create_bucket)
    * [`get_file_chunked()`](virt_s3.md#virt_s3get_file_chunked)
    * [`get_file()`](virt_s3.md#virt_s3get_file)
    * [`get_image()`](virt_s3.md#virt_s3get_image)
    * [`get_files_generator()`](virt_s3.md#virt_s3get_files_generator)
    * [`get_files_batch()`](virt_s3.md#virt_s3get_files_batch)
    * [`list_dirs()`](virt_s3.md#virt_s3list_dirs)
    * [`get_valid_file_paths()`](virt_s3.md#virt_s3get_valid_file_paths)
    * [`file_exists()`](virt_s3.md#virt_s3file_exists)
    * [`upload_data()`](virt_s3.md#virt_s3upload_data)
    * [`delete_file()`](virt_s3.md#virt_s3delete_file)
    * [`delete_files_by_dir()`](virt_s3.md#virt_s3delete_files_by_dir)
    * [`archive_zip_as_buffer()`](virt_s3.md#virt_s3archive_zip_as_buffer)
    * [`archive_tar_as_buffer()`](virt_s3.md#virt_s3archive_tar_as_buffer)
    * [`extract_archive_file()`](virt_s3.md#virt_s3extract_archive_file)
    * [`read_parquet_file_df()`](virt_s3.md#virt_s3read_parquet_file_df)
    * [`write_parquet_file_df()`](virt_s3.md#virt_s3write_parquet_file_df)
    * [`format_bytes()`](virt_s3.md#virt_s3format_bytes)
  * [Submodules](virt_s3.md#submodules)
  * [virt_s3.s3 module](virt_s3.md#module-virt_s3s3)
    * [`PredictConnectionStoreParams`](virt_s3.md#virt_s3s3PredictConnectionStoreParams)
    * [`S3Params`](virt_s3.md#virt_s3s3S3Params)
    * [`S3SessionManager`](virt_s3.md#virt_s3s3S3SessionManager)
    * [`PerformanceMetrics`](virt_s3.md#virt_s3s3PerformanceMetrics)
    * [`PerformanceRecord`](virt_s3.md#virt_s3s3PerformanceRecord)
    * [`UploadDownloadPerformanceManager`](virt_s3.md#virt_s3s3UploadDownloadPerformanceManager)
    * [`manage_s3_session()`](virt_s3.md#virt_s3s3manage_s3_session)
    * [`get_s3_default_params()`](virt_s3.md#virt_s3s3get_s3_default_params)
    * [`get_s3_session_client()`](virt_s3.md#virt_s3s3get_s3_session_client)
    * [`create_s3_bucket()`](virt_s3.md#virt_s3s3.create_s3_bucket)
    * [`get_s3_file_chunked()`](virt_s3.md#virt_s3s3get_s3_file_chunked)
    * [`get_s3_file_simple()`](virt_s3.md#virt_s3s3get_s3_file_simple)
    * [`get_s3_file_transfer()`](virt_s3.md#virt_s3s3get_s3_file_transfer)
    * [`get_s3_file_disk()`](virt_s3.md#virt_s3s3get_s3_file_disk)
    * [`get_s3_file()`](virt_s3.md#virt_s3s3get_s3_file)
    * [`get_s3_image()`](virt_s3.md#virt_s3s3get_s3_image)
    * [`get_s3_files_generator()`](virt_s3.md#virt_s3s3get_s3_files_generator)
    * [`get_s3_files_batch()`](virt_s3.md#virt_s3s3get_s3_files_batch)
    * [`list_s3_folders()`](virt_s3.md#virt_s3s3list_s3_folders)
    * [`get_valid_s3_keys()`](virt_s3.md#virt_s3s3get_valid_s3_keys)
    * [`key_exists_s3()`](virt_s3.md#virt_s3s3key_exists_s3)
    * [`upload_to_s3_simple()`](virt_s3.md#virt_s3s3upload_to_s3_simple)
    * [`upload_to_s3_transfer()`](virt_s3.md#virt_s3s3upload_to_s3_transfer)
    * [`upload_to_s3_file()`](virt_s3.md#virt_s3s3upload_to_s3_file)
    * [`upload_to_s3_folder()`](virt_s3.md#virt_s3s3upload_to_s3_folder)
    * [`upload_to_s3()`](virt_s3.md#virt_s3s3upload_to_s3)
    * [`delete_s3_object()`](virt_s3.md#virt_s3s3delete_s3_object)
    * [`delete_s3_objects_by_prefix()`](virt_s3.md#virt_s3s3delete_s3_objects_by_prefix)
    * [`extract_archive_file_s3()`](virt_s3.md#virt_s3s3extract_archive_file_s3)
  * [virt_s3.fs module](virt_s3.md#module-virt_s3fs)
    * [`LocalFSParams`](virt_s3.md#virt_s3fsLocalFSParams)
    * [`LocalFSSessionManager`](virt_s3.md#virt_s3fsLocalFSSessionManager)
    * [`get_local_fs_params()`](virt_s3.md#virt_s3fsget_local_fs_params)
    * [`fix_fs_path()`](virt_s3.md#virt_s3fsfix_fs_path)
    * [`create_fs_bucket()`](virt_s3.md#virt_s3fscreate_fs_bucket)
    * [`get_fs_file_chunked()`](virt_s3.md#virt_s3fsget_fs_file_chunked)
    * [`get_fs_file_disk()`](virt_s3.md#virt_s3fsget_fs_file_disk)
    * [`get_fs_file()`](virt_s3.md#virt_s3fsget_fs_file)
    * [`get_fs_image()`](virt_s3.md#virt_s3fsget_fs_image)
    * [`get_fs_files_generator()`](virt_s3.md#virt_s3fsget_fs_files_generator)
    * [`get_fs_files_batch()`](virt_s3.md#virt_s3fsget_fs_files_batch)
    * [`list_fs_folders()`](virt_s3.md#virt_s3fslist_fs_folders)
    * [`get_valid_fs_fpaths()`](virt_s3.md#virt_s3fsget_valid_fs_fpaths)
    * [`fpath_exists_fs()`](virt_s3.md#virt_s3fsfpath_exists_fs)
    * [`upload_to_fs_disk()`](virt_s3.md#virt_s3fsupload_to_fs_disk)
    * [`upload_to_fs_folder()`](virt_s3.md#virt_s3fsupload_to_fs_folder)
    * [`upload_to_fs()`](virt_s3.md#virt_s3fsupload_to_fs)
    * [`delete_fs_file()`](virt_s3.md#virt_s3fsdelete_fs_file)
    * [`delete_fs_files_by_dir()`](virt_s3.md#virt_s3fsdelete_fs_files_by_dir)
    * [`extract_archive_file_fs()`](virt_s3.md#virt_s3fsextract_archive_file_fs)
  * [virt_s3.utils module](virt_s3.md#module-virt_s3utils)
    * [`ImageFormatType`](virt_s3.md#virt_s3utilsImageFormatType)
    * [`get_custom_logger()`](virt_s3.md#virt_s3utilsget_custom_logger)
    * [`archive_zip_as_buffer()`](virt_s3.md#virt_s3utilsarchive_zip_as_buffer)
    * [`archive_tar_as_buffer()`](virt_s3.md#virt_s3utilsarchive_tar_as_buffer)
    * [`extract_archive_file()`](virt_s3.md#virt_s3utilsextract_archive_file)
    * [`format_bytes()`](virt_s3.md#virt_s3utilsformat_bytes)
    * [`run_async_func_in_new_event_loop_in_thread()`](virt_s3.md#virt_s3utilsrun_async_func_in_new_event_loop_in_thread)
    * [`run_concurrent_tasks()`](virt_s3.md#virt_s3utilsrun_concurrent_tasks)
  * [virt_s3.extras module](virt_s3.md#module-virt_s3extras)
    * [`read_parquet_file_df()`](virt_s3.md#virt_s3extrasread_parquet_file_df)
    * [`write_parquet_file_df()`](virt_s3.md#virt_s3extraswrite_parquet_file_df)
    * [`FileValidator`](virt_s3.md#virt_s3extrasFileValidator)
    * [`JSONFileValidator`](virt_s3.md#virt_s3extrasJSONFileValidator)
    * [`CSVFileValidator`](virt_s3.md#virt_s3extrasCSVFileValidator)
    * [`ParquetFileValidator`](virt_s3.md#virt_s3extrasParquetFileValidator)
